# -*- coding: utf-8 -*-
from setuphelpers import *


app_install_path = "/Applications/VirtualBox.app"
app_uninstall_tool = makepath(app_install_path, "VirtualBox_Uninstall.tool")
app_vbm = makepath(app_install_path, "Contents", "MacOS", "VBoxManage")


def install():
    bin_name = glob.glob("VirtualBox-*.dmg")[0]

    # Avoid VMs to be shutted unexpectedl
    if isrunning("virtualbox") and not force:
        error("ERROR: VirtualBox is running")

    # Uninstalling older major versions of the software
    for to_uninstall in installed_softwares("VirtualBox"):
        if Version(to_uninstall["version"], 1) < Version(control.get_software_version(), 1) or force:
            print("Removing: %s (%s)" % (to_uninstall["name"], to_uninstall["version"]))
            killalltasks(control.get_impacted_process_list())
            if isfile(app_uninstall_tool):
                uninstall()
            else:
                if isdir(app_install_path):
                    print("uninstall_tool not installed, removing app instead")
                    remove_tree(app_install_path)

    install_dmg(bin_name, min_version=control.get_software_version())

    # Copying uninstaller
    mount_dmg(bin_name)
    filecopyto("/Volumes/VirtualBox/VirtualBox_Uninstall.tool", app_uninstall_tool)
    unmount_dmg("/Volumes/VirtualBox")

    # Remove all file extpack
    for file in glob.glob(makepath(app_install_path, "Oracle_VM_VirtualBox_Extension_Pack-*.vbox-extpack")):
        print("Removing: %s" % file)
        remove_file(file)

    # Copy new extpack
    for ext in glob.glob("Oracle_VM_VirtualBox_Extension_Pack-*.vbox-extpack"):
        print("Copying: %s to: %s" % (ext, app_install_path))
        filecopyto(ext, app_install_path)
        # Install new extpack
        try:
            print(
                run(
                    'echo y | "%s" extpack install --replace "%s" --accept-license=33d7284dc4a0ece381196fda3cfe2ed0e1e8e7ed7f27b9a9ebc4ee22e24bd23c'
                    % (app_vbm, ext)
                )
            )
        except:
            print(run('"%s" extpack cleanup' % (app_vbm)))
            print(
                run(
                    'echo y | "%s" extpack install --replace "%s" --accept-license=33d7284dc4a0ece381196fda3cfe2ed0e1e8e7ed7f27b9a9ebc4ee22e24bd23c'
                    % (app_vbm, ext)
                )
            )


def session_setup():
    print("Disabling: Auto update checks")
    run('"%s" setextradata global GUI/UpdateDate never' % app_vbm)


def uninstall():
    print("uninstalling Virtualbox with uninstall tool")
    print(run(f"{app_uninstall_tool} --unattended"))
    if not installed_softwares("virtualbox"):
        if isdir(app_install_path):
            remove_tree(app_install_path)

        if isfile(app_uninstall_tool):
            remove_file(app_uninstall_tool)
